==> openshift-model-monitoring-5.9.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AlertingSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class AlertingSpecFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent<A>{
  public AlertingSpecFluentImpl() {
  }
  public AlertingSpecFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.AlertingSpec instance) {
    this.withAlertmanagers(instance.getAlertmanagers()); 
  }
  private java.util.List<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder> alertmanagers =  new java.util.ArrayList<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder>();
  public A addToAlertmanagers(java.lang.Integer index,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item) {
    if (this.alertmanagers == null) {this.alertmanagers = new java.util.ArrayList<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder>();}
    io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder builder = new io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder(item);_visitables.get("alertmanagers").add(index >= 0 ? index : _visitables.get("alertmanagers").size(), builder);this.alertmanagers.add(index >= 0 ? index : alertmanagers.size(), builder); return (A)this;
  }
  public A setToAlertmanagers(java.lang.Integer index,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item) {
    if (this.alertmanagers == null) {this.alertmanagers = new java.util.ArrayList<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder>();}
    io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder builder = new io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder(item);
    if (index < 0 || index >= _visitables.get("alertmanagers").size()) { _visitables.get("alertmanagers").add(builder); } else { _visitables.get("alertmanagers").set(index, builder);}
    if (index < 0 || index >= alertmanagers.size()) { alertmanagers.add(builder); } else { alertmanagers.set(index, builder);}
     return (A)this;
  }
  public A addToAlertmanagers(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints... items) {
    if (this.alertmanagers == null) {this.alertmanagers = new java.util.ArrayList<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder>();}
    for (io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item : items) {io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder builder = new io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder(item);_visitables.get("alertmanagers").add(builder);this.alertmanagers.add(builder);} return (A)this;
  }
  public A addAllToAlertmanagers(java.util.Collection<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints> items) {
    if (this.alertmanagers == null) {this.alertmanagers = new java.util.ArrayList<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder>();}
    for (io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item : items) {io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder builder = new io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder(item);_visitables.get("alertmanagers").add(builder);this.alertmanagers.add(builder);} return (A)this;
  }
  public A removeFromAlertmanagers(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints... items) {
    for (io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item : items) {io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder builder = new io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder(item);_visitables.get("alertmanagers").remove(builder);if (this.alertmanagers != null) {this.alertmanagers.remove(builder);}} return (A)this;
  }
  public A removeAllFromAlertmanagers(java.util.Collection<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints> items) {
    for (io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item : items) {io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder builder = new io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder(item);_visitables.get("alertmanagers").remove(builder);if (this.alertmanagers != null) {this.alertmanagers.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromAlertmanagers(java.util.function.Predicate<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder> predicate) {
    if (alertmanagers == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder> each = alertmanagers.iterator();
    final List visitables = _visitables.get("alertmanagers");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildAlertmanagers instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints> getAlertmanagers() {
    return build(alertmanagers);
  }
  public java.util.List<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints> buildAlertmanagers() {
    return build(alertmanagers);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints buildAlertmanager(java.lang.Integer index) {
    return this.alertmanagers.get(index).build();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints buildFirstAlertmanager() {
    return this.alertmanagers.get(0).build();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints buildLastAlertmanager() {
    return this.alertmanagers.get(alertmanagers.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints buildMatchingAlertmanager(java.util.function.Predicate<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder> predicate) {
    for (io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder item: alertmanagers) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingAlertmanager(java.util.function.Predicate<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder> predicate) {
    for (io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder item: alertmanagers) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withAlertmanagers(java.util.List<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints> alertmanagers) {
    if (this.alertmanagers != null) { _visitables.get("alertmanagers").removeAll(this.alertmanagers);}
    if (alertmanagers != null) {this.alertmanagers = new java.util.ArrayList<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder>(); for (io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item : alertmanagers){this.addToAlertmanagers(item);}} else { this.alertmanagers = null;} return (A) this;
  }
  public A withAlertmanagers(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints... alertmanagers) {
    if (this.alertmanagers != null) {this.alertmanagers.clear();}
    if (alertmanagers != null) {for (io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item :alertmanagers){ this.addToAlertmanagers(item);}} return (A) this;
  }
  public java.lang.Boolean hasAlertmanagers() {
    return alertmanagers != null && !alertmanagers.isEmpty();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<A> addNewAlertmanager() {
    return new io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluentImpl.AlertmanagersNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<A> addNewAlertmanagerLike(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluentImpl.AlertmanagersNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<A> setNewAlertmanagerLike(java.lang.Integer index,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluentImpl.AlertmanagersNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<A> editAlertmanager(java.lang.Integer index) {
    if (alertmanagers.size() <= index) throw new RuntimeException("Can't edit alertmanagers. Index exceeds size.");
    return setNewAlertmanagerLike(index, buildAlertmanager(index));
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<A> editFirstAlertmanager() {
    if (alertmanagers.size() == 0) throw new RuntimeException("Can't edit first alertmanagers. The list is empty.");
    return setNewAlertmanagerLike(0, buildAlertmanager(0));
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<A> editLastAlertmanager() {
    int index = alertmanagers.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last alertmanagers. The list is empty.");
    return setNewAlertmanagerLike(index, buildAlertmanager(index));
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<A> editMatchingAlertmanager(java.util.function.Predicate<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder> predicate) {
    int index = -1;
    for (int i=0;i<alertmanagers.size();i++) { 
    if (predicate.test(alertmanagers.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching alertmanagers. No match found.");
    return setNewAlertmanagerLike(index, buildAlertmanager(index));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AlertingSpecFluentImpl that = (AlertingSpecFluentImpl) o;
    if (alertmanagers != null ? !alertmanagers.equals(that.alertmanagers) :that.alertmanagers != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(alertmanagers,  super.hashCode());
  }
  public class AlertmanagersNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    AlertmanagersNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder(this, item);
    }
    AlertmanagersNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) AlertingSpecFluentImpl.this.setToAlertmanagers(index,builder.build());
    }
    public N endAlertmanager() {
      return and();
    }
    
  }
  
}

==> openshift-model-monitoring-5.11.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AlertingSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class AlertingSpecFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent<A>{
  public AlertingSpecFluentImpl() {
  }
  public AlertingSpecFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.AlertingSpec instance) {
    this.withAlertmanagers(instance.getAlertmanagers()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder> alertmanagers =  new java.util.ArrayList<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToAlertmanagers(java.lang.Integer index,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item) {
    if (this.alertmanagers == null) {this.alertmanagers = new java.util.ArrayList<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder>();}
    io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder builder = new io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder(item);_visitables.get("alertmanagers").add(index >= 0 ? index : _visitables.get("alertmanagers").size(), builder);this.alertmanagers.add(index >= 0 ? index : alertmanagers.size(), builder); return (A)this;
  }
  public A setToAlertmanagers(java.lang.Integer index,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item) {
    if (this.alertmanagers == null) {this.alertmanagers = new java.util.ArrayList<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder>();}
    io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder builder = new io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder(item);
    if (index < 0 || index >= _visitables.get("alertmanagers").size()) { _visitables.get("alertmanagers").add(builder); } else { _visitables.get("alertmanagers").set(index, builder);}
    if (index < 0 || index >= alertmanagers.size()) { alertmanagers.add(builder); } else { alertmanagers.set(index, builder);}
     return (A)this;
  }
  public A addToAlertmanagers(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints... items) {
    if (this.alertmanagers == null) {this.alertmanagers = new java.util.ArrayList<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder>();}
    for (io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item : items) {io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder builder = new io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder(item);_visitables.get("alertmanagers").add(builder);this.alertmanagers.add(builder);} return (A)this;
  }
  public A addAllToAlertmanagers(java.util.Collection<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints> items) {
    if (this.alertmanagers == null) {this.alertmanagers = new java.util.ArrayList<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder>();}
    for (io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item : items) {io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder builder = new io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder(item);_visitables.get("alertmanagers").add(builder);this.alertmanagers.add(builder);} return (A)this;
  }
  public A removeFromAlertmanagers(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints... items) {
    for (io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item : items) {io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder builder = new io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder(item);_visitables.get("alertmanagers").remove(builder);if (this.alertmanagers != null) {this.alertmanagers.remove(builder);}} return (A)this;
  }
  public A removeAllFromAlertmanagers(java.util.Collection<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints> items) {
    for (io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item : items) {io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder builder = new io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder(item);_visitables.get("alertmanagers").remove(builder);if (this.alertmanagers != null) {this.alertmanagers.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromAlertmanagers(java.util.function.Predicate<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder> predicate) {
    if (alertmanagers == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder> each = alertmanagers.iterator();
    final List visitables = _visitables.get("alertmanagers");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildAlertmanagers instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints> getAlertmanagers() {
    return build(alertmanagers);
  }
  public java.util.List<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints> buildAlertmanagers() {
    return build(alertmanagers);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints buildAlertmanager(java.lang.Integer index) {
    return this.alertmanagers.get(index).build();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints buildFirstAlertmanager() {
    return this.alertmanagers.get(0).build();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints buildLastAlertmanager() {
    return this.alertmanagers.get(alertmanagers.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints buildMatchingAlertmanager(java.util.function.Predicate<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder> predicate) {
    for (io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder item: alertmanagers) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingAlertmanager(java.util.function.Predicate<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder> predicate) {
    for (io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder item: alertmanagers) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withAlertmanagers(java.util.List<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints> alertmanagers) {
    if (this.alertmanagers != null) { _visitables.get("alertmanagers").removeAll(this.alertmanagers);}
    if (alertmanagers != null) {this.alertmanagers = new java.util.ArrayList<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder>(); for (io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item : alertmanagers){this.addToAlertmanagers(item);}} else { this.alertmanagers = null;} return (A) this;
  }
  public A withAlertmanagers(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints... alertmanagers) {
    if (this.alertmanagers != null) {this.alertmanagers.clear();}
    if (alertmanagers != null) {for (io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item :alertmanagers){ this.addToAlertmanagers(item);}} return (A) this;
  }
  public java.lang.Boolean hasAlertmanagers() {
    return alertmanagers != null && !alertmanagers.isEmpty();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<A> addNewAlertmanager() {
    return new io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluentImpl.AlertmanagersNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<A> addNewAlertmanagerLike(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluentImpl.AlertmanagersNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<A> setNewAlertmanagerLike(java.lang.Integer index,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluentImpl.AlertmanagersNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<A> editAlertmanager(java.lang.Integer index) {
    if (alertmanagers.size() <= index) throw new RuntimeException("Can't edit alertmanagers. Index exceeds size.");
    return setNewAlertmanagerLike(index, buildAlertmanager(index));
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<A> editFirstAlertmanager() {
    if (alertmanagers.size() == 0) throw new RuntimeException("Can't edit first alertmanagers. The list is empty.");
    return setNewAlertmanagerLike(0, buildAlertmanager(0));
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<A> editLastAlertmanager() {
    int index = alertmanagers.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last alertmanagers. The list is empty.");
    return setNewAlertmanagerLike(index, buildAlertmanager(index));
  }
  public io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<A> editMatchingAlertmanager(java.util.function.Predicate<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder> predicate) {
    int index = -1;
    for (int i=0;i<alertmanagers.size();i++) { 
    if (predicate.test(alertmanagers.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching alertmanagers. No match found.");
    return setNewAlertmanagerLike(index, buildAlertmanager(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AlertingSpecFluentImpl that = (AlertingSpecFluentImpl) o;
    if (alertmanagers != null ? !alertmanagers.equals(that.alertmanagers) :that.alertmanagers != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(alertmanagers,  additionalProperties,  super.hashCode());
  }
  public class AlertmanagersNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent.AlertmanagersNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    AlertmanagersNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpoints item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder(this, item);
    }
    AlertmanagersNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) AlertingSpecFluentImpl.this.setToAlertmanagers(index,builder.build());
    }
    public N endAlertmanager() {
      return and();
    }
    
  }
  
}
